@@ -1,6 +1,7 @@
 """
 A module for preprocessing lists.
 """
+import numpy as np
 
 
 def delete_duplicates(list):
@@ -58,3 +59,33 @@ def delete_list_item_based_on_index_from_another_list(item_list, index_list):
     """
     for index in sorted(index_list, reverse=True):
         del item_list[index]
+
+
+def maxlength(list_of_lists):
+    """
+    Return the maximum length of a list of lists.
+    """
+    return max([len(l) for l in list_of_lists])
+
+
+def minlength(list_of_lists):
+    """
+    Return the minimum length of a list of lists.
+    """
+    return min([len(l) for l in list_of_lists])
+
+
+def maxlength_idx(list):
+    """
+    Return the index of the list with the maximum length.
+    """
+    list_len = [len(i) for i in list]
+    return np.argmax(np.array(list_len))
+
+
+def minlength_idx(list):
+    """
+    Return the index of the list with the minimum length.
+    """
+    list_len = [len(i) for i in list]
+    return np.argmin(np.array(list_len))
